@@ -64,7 +64,6 @@ KWinScreenEdgesConfig::KWinScreenEdgesConfig(QWidget* parent, const QVariantList
     connect(m_ui->quickMaximizeBox, SIGNAL(stateChanged(int)), this, SLOT(groupChanged()));
     connect(m_ui->quickTileBox, SIGNAL(stateChanged(int)), this, SLOT(groupChanged()));
 
-    m_defaultPrefs.detect(); // Driver-specific config detection
     load();
 }
 
@@ -195,6 +194,7 @@ void KWinScreenEdgesConfig::monitorInit()
     } else {
         monitorAddItem(services.first()->name() + " - " + i18n("All Desktops"));
         monitorAddItem(services.first()->name() + " - " + i18n("Current Desktop"));
+        monitorAddItem(services.first()->name() + " - " + i18n("Current Application"));
     }
     services = trader->query("KWin/Effect", "[X-KDE-PluginInfo-Name] == 'kwin4_effect_desktopgrid'");
     if (services.isEmpty()) {
@@ -270,6 +270,13 @@ void KWinScreenEdgesConfig::monitorLoad()
     foreach (int i, list) {
         monitorChangeEdge(ElectricBorder(i), int(PresentWindowsCurrent));
     }
+    // PresentWindows BorderActivateClass
+    list.clear();
+    list.append(int(ElectricNone));
+    list = presentWindowsConfig.readEntry("BorderActivateClass", list);
+    foreach (int i, list) {
+        monitorChangeEdge(ElectricBorder(i), int(PresentWindowsClass));
+    }
 
     // Desktop Grid
     KConfigGroup gridConfig(m_config, "Effect-DesktopGrid");
@@ -365,6 +372,8 @@ void KWinScreenEdgesConfig::monitorSave()
                                     monitorCheckEffectHasEdge(int(PresentWindowsAll)));
     presentWindowsConfig.writeEntry("BorderActivate",
                                     monitorCheckEffectHasEdge(int(PresentWindowsCurrent)));
+    presentWindowsConfig.writeEntry("BorderActivateClass",
+                                    monitorCheckEffectHasEdge(int(PresentWindowsClass)));
 
     // Desktop Grid
     KConfigGroup gridConfig(m_config, "Effect-DesktopGrid");
@@ -402,7 +411,7 @@ void KWinScreenEdgesConfig::monitorShowEvent()
 {
     // Check if they are enabled
     KConfigGroup config(m_config, "Compositing");
-    if (config.readEntry("Enabled", m_defaultPrefs.recommendCompositing())) {
+    if (config.readEntry("Enabled", true)) {
         // Compositing enabled
         config = KConfigGroup(m_config, "Plugins");
 
